Index: Source/core/dom/TreeScope.h |
diff --git a/Source/core/dom/TreeScope.h b/Source/core/dom/TreeScope.h |
index 62b9afdc1aa688f2da9d253590cb6b8662906364..e19afd1eb6212d82d3da8ddeb8794f1f6f22a366 100644 |
--- a/Source/core/dom/TreeScope.h |
+++ b/Source/core/dom/TreeScope.h |
@@ -105,9 +105,12 @@ public: |
void trace(Visitor*); |
- // We can't pass TreeScope pointer into Visitor::visit function directly because it does not coincide with the actual start of the object and |
- // visitor has to access object header. Thus we need a helper method that would correctly adjust the pointer before passing it into the visitor. |
- virtual void visitWith(Visitor*) const; |
+ // We can't pass TreeScope pointer into Visitor::mark function |
+ // directly because it does not coincide with the actual start of |
+ // the object and visitor has to access object header. Thus we |
+ // need a helper method that correctly adjusts the pointer |
+ // before passing it into the visitor. |
+ virtual void adjustAndMark(Visitor*) const; |
protected: |
static TreeScope* create() |
@@ -161,7 +164,7 @@ TreeScope* commonTreeScope(Node*, Node*); |
template<> class TraceTrait<TreeScope> { |
public: |
- static void visit(Visitor* v, const TreeScope* self) { self->visitWith(v); } |
+ static void mark(Visitor* v, const TreeScope* self) { self->adjustAndMark(v); } |
static intptr_t getTypeMarker() { return 0; } |
static void checkTypeMarker(Visitor* visitor, const TreeScope* t) { } |
static void trace(Visitor* visitor, void* self) |